==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ajouter une propriété personnalisée</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Valeur :</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">Type : </translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+348"/>
        <source>Geometry</source>
        <translation>Géométrie</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Custom</source>
        <translation>Personnalisé</translation>
    </message>
    <message>
        <location line="+135"/>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Retirer ce propriété à partir des objets sélectionnés</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Add custom property to selected objects</source>
        <translation>Ajouter une propriété personnalisée pour les objets sélectionnés</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="obsolete">Gauche</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="obsolete">Centrer</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="obsolete">Droite</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translation type="obsolete">Alignée</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="obsolete">En haut</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="obsolete">Milieu</translation>
    </message>
    <message>
        <location line="-435"/>
        <source>*VARIES*</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>*VARIABLE*</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>:</source>
        <translatorcomment>--ignored colon--
--file: qt_fr.ts--
Document Chargé :
Dessin enregistré : %1</translatorcomment>
        <translation> :</translation>
    </message>
    <message>
        <location line="+137"/>
        <source>No Selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Aucune sélection</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Dependent Entities</source>
        <translation>Entités dépendantes</translation>
    </message>
    <message>
        <location line="+242"/>
        <source>All</source>
        <translatorcomment>--google--
Partage &amp;Horizontal
Partage Horizontal
Renommer tous les Blocs et Objets Insérés</translatorcomment>
        <translation>Tous</translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Ajouter une propriété personnalisée</translation>
    </message>
    <message>
        <source>Fit</source>
        <translatorcomment>--google--
Ajuster à la page
Premier point ajustement
Point ajustement suivant</translatorcomment>
        <translation type="obsolete">Ajustement</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="obsolete">En bas</translation>
    </message>
    <message>
        <source>Base</source>
        <translatorcomment>--google--
Dessine des arcs tangents à une entité de base
Indiquer l&apos;entité de base
Sélectionner l&apos;entité de base</translatorcomment>
        <translation type="obsolete">Base</translation>
    </message>
    <message>
        <location line="+157"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location line="+119"/>
        <source>Use auto measurement</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Utilisez la mesure automatique</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>-</source>
        <translatorcomment>--google--
(Dé)Verroui&amp;ller zéro relatif
(Dé)Verrouiller zéro relatif
Verrouille ou déverrouille le point zéro relatif</translatorcomment>
        <translation type="obsolete">-</translation>
    </message>
    <message>
        <location line="+317"/>
        <location line="+12"/>
        <source>Property Editor</source>
        <translation>Éditeur de propriétés</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: qt_fr.ts--</translatorcomment>
        <translation>Sélection :</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General</source>
        <translation>Générale</translation>
    </message>
    <message>
        <location line="+163"/>
        <source>Move Selection to a New Layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Déplacer la sélection dans un nouveau calque</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Handle:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Poignée:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ajouter une propriété personnalisée</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Valeur :</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">Type : </translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <source>Geometry</source>
        <translation type="vanished">Géométrie</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.js" line="+389"/>
        <source>Custom</source>
        <translation>Personnalisé</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Retirer ce propriété à partir des objets sélectionnés</translation>
    </message>
    <message>
        <location line="+90"/>
        <source>Add custom property to selected objects</source>
        <translation>Ajouter une propriété personnalisée pour les objets sélectionnés</translation>
    </message>
    <message>
        <location line="+617"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="obsolete">Gauche</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="obsolete">Centrer</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="obsolete">Droite</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translation type="obsolete">Alignée</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="obsolete">En haut</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="obsolete">Milieu</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>*VARIES*</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>*VARIABLE*</translation>
    </message>
    <message>
        <location line="-1130"/>
        <source>:</source>
        <translatorcomment>--ignored colon--
--file: qt_fr.ts--
Document Chargé :
Dessin enregistré : %1</translatorcomment>
        <translation> :</translation>
    </message>
    <message>
        <location line="+150"/>
        <source>No Selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Aucune sélection</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>Propriétés spécifiques</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Entités dépendantes</translation>
    </message>
    <message>
        <location line="+310"/>
        <source>All</source>
        <translatorcomment>--google--
Partage &amp;Horizontal
Partage Horizontal
Renommer tous les Blocs et Objets Insérés</translatorcomment>
        <translation>Tous</translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Ajouter une propriété personnalisée</translation>
    </message>
    <message>
        <source>Fit</source>
        <translatorcomment>--google--
Ajuster à la page
Premier point ajustement
Point ajustement suivant</translatorcomment>
        <translation type="obsolete">Ajustement</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="obsolete">En bas</translation>
    </message>
    <message>
        <source>Base</source>
        <translatorcomment>--google--
Dessine des arcs tangents à une entité de base
Indiquer l&apos;entité de base
Sélectionner l&apos;entité de base</translatorcomment>
        <translation type="obsolete">Base</translation>
    </message>
    <message>
        <location line="+158"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location line="+121"/>
        <source>Use auto measurement</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Utilisez la mesure automatique</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>-</source>
        <translatorcomment>--google--
(Dé)Verroui&amp;ller zéro relatif
(Dé)Verrouiller zéro relatif
Verrouille ou déverrouille le point zéro relatif</translatorcomment>
        <translation type="obsolete">-</translation>
    </message>
    <message>
        <location line="+320"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>Éditeur de propriétés</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: qt_fr.ts--</translatorcomment>
        <translation>Sélection :</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Générale</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>Propriétés générales</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation>Couleur :</translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Déplacer la sélection dans un nouveau calque</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation>Échelle du type de ligne :</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>Protégé :</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Poignée :</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Afficher coordonnées z</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>Afficher les propriétés de bloc actuel et du calque actuel</translation>
    </message>
</context>
</TS>
